frustum

Function frustum 

pub fn frustum(
    left: f32,
    right: f32,
    bottom: f32,
    top: f32,
    near: f32,
    far: f32,
) -> Mat4
Creates a perspective projection from a frustum for use with DirectX and WebGPU.

Expects a right-handed Y-up view space input. Outputs NDC with Z in [0, 1] and Y-up.

Panics

Will panic if left is equal to right, if bottom is equal to top, or if near or far are less than or equal to zero, or if near is equal to far, when glam_assert is enabled.